.. -*- coding: utf-8 -*-

===============================
``pybill.lib.config`` package
===============================

.. automodule:: pybill.lib.config

``register`` module
===================

.. automodule:: pybill.lib.config.register

``entities`` module
===================

.. automodule:: pybill.lib.config.entities


``xmlreaders`` module
=====================

.. automodule:: pybill.lib.config.xmlreaders

``xmlwriters`` module
=====================

.. automodule:: pybill.lib.config.xmlwriters

